==> nextcloud-28.0.3.tgz: nextcloud/apps/comments/l10n/eu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Iruzkinak",
    "You commented" : "Iruzkindu duzu",
    "{author} commented" : "{author}-(e)k iruzkindu du",
    "You commented on %1$s" : "%1$s-en iruzkindu duzu",
    "You commented on {file}" : "{file} fitxategian iruzkina egin duzu",
    "%1$s commented on %2$s" : "%1$s-ek %2$s-en iruzkindu du",
    "{author} commented on {file}" : "{author}-(e)k {file}-en iruzkina egin du",
    "<strong>Comments</strong> for files" : "Fitxategientzako <strong>iruzkinak</strong>",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} erabiltzaileak aipatu zaitu \"{file}\"-eko iruzkin batean",
    "Files app plugin to add comments to files" : "Fitxategiak aplikazioko plugina, fitxategiei iruzkinak gehitzeko",
    "Edit comment" : "Editatu iruzkina",
    "Delete comment" : "Ezabatu iruzkina",
    "Cancel edit" : "Utzi editatzeari",
    "Post comment" : "Argitaratu iruzkina",
    "@ for mentions, : for emoji, / for smart picker" : "@ aipamenetarako, : emojientzako, / hautatzaile adimentsurako",
    "Could not reload comments" : "Ezin izan dira iruzkinak freskatu",
    "No comments yet, start the conversation!" : "Oraindik ez dago iruzkinik, izan zaitez lehena zerbait esanez!",
    "No more messages" : "Ez da mezu gehiagorik",
    "Retry" : "Saiatu berriro",
    "Failed to mark comments as read" : "Iruzkinak irakurritako gisa markatzeak huts egin du",
    "Unable to load the comments list" : "Ezin da iruzkinen zerrenda kargatu",
    "_1 new comment_::_{unread} new comments_" : ["Iruzkin berri 1","{unread} iruzkin berri"],
    "Comment" : "Iruzkindu",
    "An error occurred while trying to edit the comment" : "Errorea gertatu da iruzkina editatzen saiatzean",
    "Comment deleted" : "Iruzkina ezabatu da",
    "An error occurred while trying to delete the comment" : "Errorea gertatu da iruzkina ezabatzen saiatzean",
    "An error occurred while trying to create the comment" : "Errorea gertatu da iruzkina sortzen saiatzean",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "\"{file}\"-n aipatu zaituzte, dagoeneko ezabatu den erabiltzaile baten iruzkin batean",
    "_%n unread comment_::_%n unread comments_" : ["iruzkin %n irakurri gabe","%n iruzkin irakurri gabe"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/comments/l10n/eu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Iruzkinak",
    "You commented" : "Iruzkindu duzu",
    "{author} commented" : "{author}-(e)k iruzkindu du",
    "You commented on %1$s" : "%1$s-en iruzkindu duzu",
    "You commented on {file}" : "{file} fitxategian iruzkina egin duzu",
    "%1$s commented on %2$s" : "%1$s-ek %2$s-en iruzkindu du",
    "{author} commented on {file}" : "{author}-(e)k {file}-en iruzkina egin du",
    "<strong>Comments</strong> for files" : "Fitxategientzako <strong>iruzkinak</strong>",
    "Files" : "Fitxategiak",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "\"{file}\"-n aipatu zaituzte, dagoeneko ezabatu den kontu baten iruzkin batean",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} erabiltzaileak aipatu zaitu \"{file}\"-eko iruzkin batean",
    "Files app plugin to add comments to files" : "Fitxategiak aplikazioko plugina, fitxategiei iruzkinak gehitzeko",
    "Edit comment" : "Editatu iruzkina",
    "Delete comment" : "Ezabatu iruzkina",
    "Cancel edit" : "Utzi editatzeari",
    "New comment" : "Iruzkin berria",
    "Write a comment …" : "Idatzi iruzkin bat ...",
    "Post comment" : "Argitaratu iruzkina",
    "@ for mentions, : for emoji, / for smart picker" : "@ aipamenetarako, : emojientzako, / hautatzaile adimentsurako",
    "Could not reload comments" : "Ezin izan dira iruzkinak freskatu",
    "No comments yet, start the conversation!" : "Oraindik ez dago iruzkinik, izan zaitez lehena zerbait esanez!",
    "No more messages" : "Ez da mezu gehiagorik",
    "Retry" : "Saiatu berriro",
    "Failed to mark comments as read" : "Iruzkinak irakurritako gisa markatzeak huts egin du",
    "Unable to load the comments list" : "Ezin da iruzkinen zerrenda kargatu",
    "_1 new comment_::_{unread} new comments_" : ["Iruzkin berri 1","{unread} iruzkin berri"],
    "Comment" : "Iruzkindu",
    "An error occurred while trying to edit the comment" : "Errorea gertatu da iruzkina editatzen saiatzean",
    "Comment deleted" : "Iruzkina ezabatu da",
    "An error occurred while trying to delete the comment" : "Errorea gertatu da iruzkina ezabatzen saiatzean",
    "An error occurred while trying to create the comment" : "Errorea gertatu da iruzkina sortzen saiatzean"
},
"nplurals=2; plural=(n != 1);");
